@@ -62,7 +62,7 @@ ebi('op_up2k').innerHTML = (
 	'		</td>\n' +
 	'		<td rowspan="2">\n' +
 	'			<input type="checkbox" id="ask_up" />\n' +
-	'			<label for="ask_up" tt="ask for confirmation befofre upload starts">💭</label>\n' +
+	'			<label for="ask_up" tt="ask for confirmation before upload starts">💭</label>\n' +
 	'		</td>\n' +
 	'		<td rowspan="2">\n' +
 	'			<input type="checkbox" id="flag_en" />\n' +
@@ -1452,6 +1452,13 @@ function play_linked() {
 };
 
 
+(function () {
+	var d = mknod('div');
+	d.setAttribute('id', 'acc_info');
+	document.body.insertBefore(d, ebi('ops'));
+})();
+
+
 var thegrid = (function () {
 	var lfiles = ebi('files'),
 		gfiles = mknod('div');
@@ -1714,12 +1721,13 @@ var thegrid = (function () {
 
 
 function tree_scrollto() {
-	var act = QS('#treeul a.hl');
-	if (!act)
+	var act = QS('#treeul a.hl'),
+		ul = act ? act.offsetParent : null;
+
+	if (!ul)
 		return;
 
 	var ctr = ebi('tree'),
-		ul = act.offsetParent,
 		em = parseFloat(getComputedStyle(act).fontSize),
 		top = act.offsetTop + ul.offsetTop,
 		min = top - 11 * em,
@@ -2306,7 +2314,12 @@ var treectl = (function () {
 		var fun = treectl.dir_cb;
 		if (fun) {
 			treectl.dir_cb = null;
-			fun();
+			try {
+				fun();
+			}
+			catch (ex) {
+				console.log("dir_cb failed", ex);
+			}
 		}
 	}
 
@@ -2428,6 +2441,7 @@ var treectl = (function () {
 		if (this.hpush)
 			hist_push(this.top);
 
+		acct = res.acct;
 		apply_perms(res.perms);
 		despin('#files');
 		despin('#gfiles');
@@ -2544,6 +2558,10 @@ function despin(sel) {
 function apply_perms(newperms) {
 	perms = newperms || [];
 
+	ebi('acc_info').innerHTML = '<span>' + (acct != '*' ?
+		'<a href="/?pw=x">Logout ' + acct + '</a>' :
+		'<a href="/?h">Login</a>') + '</span>';
+
 	var o = QSA('#ops>a[data-perm], #u2footfoot');
 	for (var a = 0; a < o.length; a++) {
 		var display = '';
@@ -2567,12 +2585,10 @@ function apply_perms(newperms) {
 		de = document.documentElement,
 		tds = QSA('#u2conf td');
 
-	/* good idea maybe
 	clmod(de, "read", have_read);
 	clmod(de, "write", have_write);
 	clmod(de, "nread", !have_read);
 	clmod(de, "nwrite", !have_write);
-	*/
 
 	for (var a = 0; a < tds.length; a++) {
 		tds[a].style.display =
