@@ -462,6 +462,9 @@ function U2pvis(act, btns) {
 
 function fsearch_explain(e) {
     ev(e);
+    if (!has(perms, 'write'))
+        return alert('your access to this folder is Read-Only\n\n' + (acct == '*' ? 'you are currently not logged in' : 'you are currently logged in as ' + acct));
+
     alert('you are currently in file-search mode\n\nswitch to upload-mode by clicking the green magnifying glass (next to the big yellow search button), and then refresh\n\nsorry');
 }
 
@@ -493,8 +496,9 @@ function up2k_init(subtle) {
         shame = 'your browser is impressively ancient';
 
     // upload ui hidden by default, clicking the header shows it
+    var got_deps = false;
     function init_deps() {
-        if (!subtle && !window.asmCrypto) {
+        if (!got_deps && !subtle && !window.asmCrypto) {
             var fn = 'sha512.' + sha_js + '.js';
             showmodal('<h1>loading ' + fn + '</h1><h2>since ' + shame + '</h2><h4>thanks chrome</h4>');
             import_js('/.cpr/deps/' + fn, unmodal);
@@ -505,6 +509,7 @@ function up2k_init(subtle) {
                 ebi('u2foot').innerHTML = 'seems like ' + shame + ' so do that if you want more performance <span style="color:#' +
                     (sha_js == 'ac' ? 'c84">(expecting 20' : '8a5">(but dont worry too much, expect 100') + ' MiB/s)</span>';
         }
+        got_deps = true;
     }
 
     // show uploader if the user only has write-access
@@ -921,8 +926,11 @@ function up2k_init(subtle) {
                 return;
 
             clearTimeout(tto);
+            if (crashed)
+                return defer();
+
             running = true;
-            while (window['vis_exh']) {
+            while (true) {
                 var now = Date.now(),
                     is_busy = 0 !=
                         st.todo.head.length +
@@ -1004,7 +1012,7 @@ function up2k_init(subtle) {
                     mou_ikkai = true;
                 }
 
-                if (!mou_ikkai)
+                if (!mou_ikkai || crashed)
                     return defer();
             }
         }
@@ -1297,9 +1305,7 @@ function up2k_init(subtle) {
 
                     if (!response || !response.hits || !response.hits.length) {
                         smsg = '404';
-                        msg = 'not found on server';
-                        if (has(perms, 'write'))
-                            msg += ' <a href="#" onclick="fsearch_explain()" class="fsearch_explain">(explain)</a>';
+                        msg = 'not found on server <a href="#" onclick="fsearch_explain()" class="fsearch_explain">(explain)</a>';
                     }
                     else {
                         smsg = 'found';
@@ -1516,7 +1522,7 @@ function up2k_init(subtle) {
                 try { orz(xhr); } catch (ex) { vis_exh(ex + '', '', '', '', ex); }
             };
             xhr.onerror = function (xev) {
-                if (!window['vis_exh'])
+                if (crashed)
                     return;
 
                 console.log('chunkpit onerror, retrying', t);
