@@ -66,6 +66,14 @@ def get_ramdisk():
         for _ in range(10):
             try:
                 _, _ = chkcmd("diskutil", "eraseVolume", "HFS+", "cptd", devname)
+                with open("/Volumes/cptd/.metadata_never_index", "w") as f:
+                    f.write("orz")
+
+                try:
+                    shutil.rmtree("/Volumes/cptd/.fseventsd")
+                except:
+                    pass
+
                 return subdir("/Volumes/cptd")
             except Exception as ex:
                 print(repr(ex))
@@ -119,14 +127,13 @@ class VHttpConn(object):
         self.addr = ("127.0.0.1", "42069")
         self.args = args
         self.asrv = asrv
-        self.is_mp = False
+        self.nid = None
         self.log_func = log
         self.log_src = "a"
         self.lf_url = None
         self.hsrv = VHttpSrv()
         self.nreq = 0
         self.nbyte = 0
-        self.workload = 0
         self.ico = None
         self.thumbcli = None
         self.t0 = time.time()
\ No newline at end of file
